pub struct PlayerState {
pub position: usize,
pub player_position: Duration,
pub player_volume: PlayerVolume,
pub playback_state: PlaybackState,
pub tracks: Vec<Track>,
pub shuffled_tracks: Vec<Track>,
pub shuffle_state: ShuffleState,
pub loop_state: LoopState,
}Expand description
Data structure used to store playback state on the disc and in the RAM at runtime.
Fields
position: usizeThe index of the current track.
It can either point to the tracks variable or shuffled_tracks is shuffle is supported
and set to ShuffleState::On.
player_position: Durationplayer_volume: PlayerVolumeplayback_state: PlaybackStatetracks: Vec<Track>shuffled_tracks: Vec<Track>shuffle_state: ShuffleStateloop_state: LoopStateImplementations
Sourceimpl PlayerState
impl PlayerState
pub fn set_tracks(&mut self, tracks: Vec<Track>)
pub fn append_tracks(&mut self, tracks: &mut Vec<Track>)
pub fn set_shuffle_state(&mut self, shuffle_state: ShuffleState)
pub fn increment_player_position(&mut self, duration: Duration)
pub fn set_player_position(&mut self, player_position: Duration)
pub fn set_player_volume(&mut self, player_volume: PlayerVolume)
pub fn set_loop_state(&mut self, loop_state: LoopState)
pub fn set_playback_state(&mut self, playback_state: PlaybackState)
pub fn is_empty(&self) -> bool
pub fn current(&self) -> Option<&Track>
pub fn play_track(&mut self, index: usize) -> Option<&Track>
pub fn can_seek(&self) -> bool
pub fn can_play(&self) -> bool
pub fn can_pause(&self) -> bool
pub fn can_go_next(&self) -> bool
pub fn next_track(&mut self) -> Option<&Track>
pub fn can_go_previous(&self) -> bool
pub fn previous_track(&mut self) -> Option<&Track>